#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-extras
version:              0.10.2.2
visibility:           public
id:                   primitive-extras-0.10.2.2-959ZJcmpAYCDMmvP40fyye
key:                  primitive-extras-0.10.2.2-959ZJcmpAYCDMmvP40fyye
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  4051cbed658f344fc40541ce4e351e3e
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-extras-0.10.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.2.2-959ZJcmpAYCDMmvP40fyye
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    deferred-folds-0.9.18.10-7Qy7YAuzRMZGNMkJd3lzL7
    focus-1.0.3.2-K4r8d6TYSaL8JgI7TgFd9X
    foldl-1.4.18-334bPsHCjhEA5hWHSKnVfK
    list-t-1.0.5.7-5wiNHt4HfJY6yigEbdj2d7
    primitive-0.9.1.0-MBLhlhjxKECZedf7vLmE9
    primitive-unlifted-2.2.0.0-4VVXsiJibQ19xyEIG4KpkA
    profunctors-5.6.3-JnuHpSewkPTGuFv8b3nvPr
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

